@@ -395,7 +395,7 @@ class Backbone(object):
                 user_id = self.teacher_map.get(user_number) or self.student_map.get(user_number)
                 if user_id:
                     m_room.user.append(user_id)
-            res_data = self.nirvana_requester.create_classroom(m_room.nirvana_data)
+            res_data = self.nirvana_requester.create_meeting_room(m_room.nirvana_data)
             m_room.uid = res_data['uid']
             role_data = m_room.nirvana_rule_data
             if role_data:
