@@ -1,12 +1,11 @@
 import datetime
-import pymssql
 from sync.base import BaseSync
 from utils.loggerutils import logging
 from utils.dateutils import date2str
 from utils.code import get_md5_hash
 from classcard_dataclient.models.semester import SemesterV2
 from classcard_dataclient.models.schedule import RestScheduleV2, RestTableV2, PeriodSet
-from config import SQLSERVER_HOST, SQLSERVER_USER, SQLSERVER_PW, SQLSERVER_DB, SCHOOL_SEASON
+from config import SCHOOL_SEASON
 
 logger = logging.getLogger(__name__)
 
@@ -14,10 +13,7 @@ logger = logging.getLogger(__name__)
 class ScheduleSync(BaseSync):
     def __init__(self):
         super(ScheduleSync, self).__init__()
-        self.db = pymssql.connect(server=SQLSERVER_HOST, user=SQLSERVER_USER, password=SQLSERVER_PW,
-                                  database=SQLSERVER_DB)
         self.offset = 300
-        self.cur = self.db.cursor()
         self.slot_map = {}
 
     def wrap_time(self, ts):
@@ -27,7 +23,7 @@ class ScheduleSync(BaseSync):
         time_com_map = {"summer": ("summerstart", "summerend", "summerstartbefore"),
                         "winter": ("winterstart", "winterend", "winterstartbefore")}
         time_com = time_com_map[SCHOOL_SEASON]
-        sql = "SELECT id, sectionname, {}, {}, {}, ver FROM mid_attendschedule " \
+        sql = "SELECT id, sectionname, {}, {}, {}, ver FROM mid_section " \
               "ORDER BY ver".format(time_com[0], time_com[1], time_com[2])
         self.cur.execute(sql)
         rows = self.cur.fetchall()
@@ -58,5 +54,4 @@ class ScheduleSync(BaseSync):
         logger.info(">>> CREATE_REST_TABLE")
         self.client.create_semester(self.school_id, semester)
         self.client.create_rest_table(self.school_id, rest_table, is_active=True)
-        self.cur.close()
-        self.db.close()
+        self.close_db()
